Learn R Programming

plasso (version 0.1.3)

find_Xse_ind: Helper function to find the position for prespecified SE rules

Description

find_Xse_ind is a helper function that finds the position for prespecified SE rules.

Usage

find_Xse_ind(CV, ind_min, oneSE, factor)

Value

Index on the Lambda grid.

Arguments

CV

Vector of cross-validated criterion

ind_min

Index of cross-validated minimum

oneSE

Vector that contains the standard errors of the cross-validated criterion for the whole grid

factor

Factor in which direction to go: Negative values favor smaller models, positive values favor larger models