Learn R Programming

plasso (version 0.1.3)

print.cv.plasso: Print cross-validated (Post-) Lasso model

Description

Printing main insights from cross-validated (Post-) Lasso model.

Usage

# S3 method for cv.plasso
print(x, ..., digits = max(3, getOption("digits") - 3))

Value

Prints basic statistics for different lambda values of a fitted plasso object, i.e. cross-validated MSEs for both Lasso and Post-Lasso model as well as the number of active variables.

Arguments

x

cv.plasso object

...

Pass generic print options

digits

Integer, used for number formatting