find_Xse_ind is a helper function that finds the position for prespecified SE rules.
find_Xse_ind(CV, ind_min, oneSE, factor)Index on the Lambda grid.
Vector of cross-validated criterion
Index of cross-validated minimum
Vector that contains the standard errors of the cross-validated criterion for the whole grid
Factor in which direction to go: Negative values favor smaller models, positive values favor larger models