Printing main insights from cross-validated (Post-) Lasso model.
# S3 method for cv.plasso
print(x, ..., digits = max(3, getOption("digits") - 3))Prints basic statistics for different lambda values of a fitted plasso object,
i.e. cross-validated MSEs for both Lasso and Post-Lasso model as well as the number of active variables.
cv.plasso object
Pass generic print options
Integer, used for number formatting